@@ -160,7 +160,7 @@ chatty_application_show_about (GSimpleAction *action,
   if (!self->main_window)
     return;
 
-  adw_show_about_window (gtk_application_get_active_window (user_data),
+  adw_show_about_dialog (GTK_WIDGET (gtk_application_get_active_window (user_data)),
                          "application-name", _("Chats"),
                          "application-icon", CHATTY_APP_ID,
                          "version", GIT_VERSION,
@@ -191,20 +191,20 @@ show_help_cb (GObject      *object,
   g_clear_object (&object);
 
   if (error) {
-    GtkWidget *dialog;
+    AdwDialog *dialog;
     GtkWindow *window;
 
     window = gtk_application_get_active_window (GTK_APPLICATION (g_application_get_default ()));
-    dialog = adw_message_dialog_new (window, _("Error"), NULL);
-    adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
+    dialog = adw_alert_dialog_new (("Error"), NULL);
+    adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog),
                                     _("There was an error displaying help:\n%s"),
                                      error->message);
-    adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (dialog), "close", _("Close"));
+    adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "close", _("Close"));
 
-    adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "close");
-    adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (dialog), "close");
+    adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "close");
+    adw_alert_dialog_set_close_response (ADW_ALERT_DIALOG (dialog), "close");
 
-    gtk_window_present (GTK_WINDOW (dialog));
+    adw_dialog_present (dialog, GTK_WIDGET (window));
   }
 }
 
